@@ -20,12 +20,12 @@ import zipfile
 
 from typing import Dict, Iterator, List
 
-from google.protobuf import text_format
+from google.protobuf import text_format  # type: ignore
 
-import pandas
+import pandas  # type: ignore
 import requests
 
-import citylex_pb2
+import citylex_pb2   # type: ignore
 
 
 def read_textproto(path: str) -> citylex_pb2.Lexicon:
@@ -373,7 +373,7 @@ def _wikipron_uk(lexicon: citylex_pb2.Lexicon) -> None:
     counter = 0
     url = (
         "https://raw.githubusercontent.com/kylebgorman/"
-        "wikipron/master/languages/wikipron/tsv/eng_uk_phonemic.tsv"
+        "wikipron/master/data/wikipron/tsv/eng_uk_phonemic.tsv"
     )
     for line in _request_url_resource(url):
         (wordform, pron, *_) = line.rstrip().split("\t")
@@ -392,7 +392,7 @@ def _wikipron_us(lexicon: citylex_pb2.Lexicon) -> None:
     counter = 0
     url = (
         "https://raw.githubusercontent.com/kylebgorman/"
-        "wikipron/master/languages/wikipron/tsv/eng_us_phonemic.tsv"
+        "wikipron/master/data/wikipron/tsv/eng_us_phonemic.tsv"
     )
     for line in _request_url_resource(url):
         (wordform, pron, *_) = line.rstrip().split("\t")
@@ -418,6 +418,11 @@ def main() -> None:
         help="output TSV path (default: %(default)s)",
     )
     # Enables specific data sources.
+    parser.add_argument(
+        "--all-free",
+        action="store_true",
+        help="extracts all free data sources"
+    )
     parser.add_argument(
         "--celex",
         action="store_true",
@@ -425,7 +430,7 @@ def main() -> None:
         "http://catalog.ldc.upenn.edu/license/celex-user-agreement.pdf",
     )
     parser.add_argument(
-        "--celex_path",
+        "--celex-path",
         help="path to CELEX directory (usually ends in `celex2`)",
     )
     parser.add_argument(
@@ -441,13 +446,13 @@ def main() -> None:
         "http://creativecommons.org/licenses/by-nc/4.0/",
     )
     parser.add_argument(
-        "--subtlex_uk",
+        "--subtlex-uk",
         action="store_true",
         help="extract SUBTLEX-UK data (CC BY-NC-ND 2.0): "
         "http://creativecommons.org/licenses/by-nc-nd/2.0/",
     )
     parser.add_argument(
-        "--subtlex_us",
+        "--subtlex-us",
         action="store_true",
         help="extract SUBTLEX-US data (CC BY-NC-ND 2.0): "
         "http://creativecommons.org/licenses/by-nc-nd/2.0/",
@@ -465,13 +470,13 @@ def main() -> None:
         "http://creativecommons.org/licenses/by-sa/2.0/",
     )
     parser.add_argument(
-        "--wikipron_uk",
+        "--wikipron-uk",
         action="store_true",
         help="extract WikiPron UK data (CC BY-SA 3.0 Unported): "
         "http://creativecommons.org/licenses/by-sa/3.0/",
     )
     parser.add_argument(
-        "--wikipron_us",
+        "--wikipron-us",
         action="store_true",
         help="extract WikiPron US data (CC BY-SA 3.0 Unported): "
         "http://creativecommons.org/licenses/by-sa/3.0/",
@@ -487,28 +492,28 @@ def main() -> None:
             exit(1)
         _celex(args.celex_path, lexicon)
         fieldnames.extend(["celex_freq", "celex_pron"])
-    if args.cmudict:
+    if args.all_free or args.cmudict:
         _cmudict(lexicon)
         fieldnames.append("cmudict_pron")
-    if args.elp:
+    if args.all_free or args.elp:
         _elp(lexicon)
         fieldnames.extend(["elp_morph_sp", "elp_nmorph"])
-    if args.subtlex_uk:
+    if args.all_free or args.subtlex_uk:
         _subtlex_uk(lexicon)
         fieldnames.extend(["subtlex_uk_freq", "subtlex_uk_cd"])
-    if args.subtlex_us:
+    if args.all_free or args.subtlex_us:
         _subtlex_us(lexicon)
         fieldnames.extend(["subtlex_us_freq", "subtlex_us_cd"])
-    if args.udlexicons:
+    if args.all_free or args.udlexicons:
         _udlexicons(lexicon)
         fieldnames.append("udlexicons_morph")
-    if args.unimorph:
+    if args.all_free or args.unimorph:
         _unimorph(lexicon)
         fieldnames.append("unimorph_morph")
-    if args.wikipron_uk:
+    if args.all_free or args.wikipron_uk:
         _wikipron_uk(lexicon)
         fieldnames.append("wikipron_uk_pron")
-    if args.wikipron_us:
+    if args.all_free or args.wikipron_us:
         _wikipron_us(lexicon)
         fieldnames.append("wikipron_us_pron")
     if not fieldnames:
